---
title: 'Pyrgg: Python Random Graph Generator'
tags:
  - graph
  - script
  - generator
  - processing
  - random
authors:
 - name: Sepand Haghighi
   orcid: 0000-0001-9450-2375
   affiliation: 1
affiliations:
 - name: Sharif University of Technology
   index: 1
date: 18 July 2017
bibliography: paper.bib
---
						

# Summary

Pyrgg is an easy-to-use synthetic random graph generator written in Python which supports various graph file formats including DIMACS .gr files.
Pyrgg has the ability to generate graphs of different sizes and is designed to provide input files for broad range of graph-based research applications, including but not limited to testing, benchmarking and performance-analysis of graph processing frameworks. [@Zhong2012; @Chakrabarti2004]									
Pyrgg target audiences are computer scientists who study graph algorithms and graph processing frameworks.	

Graph Specifications :

- Weighted
- Signed
- Self Loop
- Parallel Arc
- Sparse
- Dense  

Supported Formats:

- DIMACS(.gr)
- CSV(.csv)
- JSON(.json)
- YAML(.yaml)
- Weighted Edge List(.wel)
- ASP(.lp)
- Trivial Graph Format(.tgf)
- UCINET DL Format(.dl)
- Pickle(.p)


See README.md from the Pyrgg repository for further details

website : pyrgg.shaghighi.ir

![Pyrgg Logo](pyrgg-logo.png)

# References
